/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'pt-br', {
	border: 'Mostra borda do iframe',
	noUrl: 'Insira a URL do iframe',
	scrolling: 'Abilita scrollbars',
	title: 'Propriedade do IFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
